==> winboard-4_0_0-src.zip: winboard/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by winboard.rc
//
#define IDM_NewGame                     100
#define IDM_LoadGame                    101
#define IDM_SaveGame                    102
#define IDM_Exit                        103
#define IDM_LoadPosition                104
#define IDM_SavePosition                105
#define IDM_EditPosition                106
#define IDM_FlipView                    107
#define IDM_MachineWhite                108
#define IDM_MachineBlack                109
#define IDM_TwoMachines                 110
#define IDM_EditGame                    111
#define IDM_Forward                     112
#define IDM_Backward                    113
#define IDM_ToEnd                       114
#define IDM_ToStart                     115
#define IDM_Pause                       116
#define IDM_CallFlag                    117
#define IDM_Draw                        118
#define IDM_Abort                       120
#define IDM_Adjourn                     122
#define IDM_Resign                      124
#define IDM_Hint                        125
#define IDM_IcsClient                   126
#define IDM_ShowCoords                  127
#define IDM_BoardSize                   128
#define IDM_Bell                        129
#define IDM_Autoflag                    130
#define IDM_TimeControl                 131
#define IDM_LoadOptions                 132
#define IDM_SaveOptions                 133
#define IDM_Monochrome                  134
#define IDM_LightSquares                135
#define IDM_DarkSquares                 136
#define IDM_WhitePieces                 137
#define IDM_BlackPieces                 138
#define IDM_MessageFont                 143
#define IDM_ClockFont                   144
#define IDM_CoordFont                   145
#define IDM_DefaultFonts                146
#define IDM_CommPort                    147
#define IDM_EditComment                 148
#define IDM_LoadNextGame                149
#define IDM_LoadPrevGame                150
#define IDM_ReloadGame                  151
#define IDM_AlwaysQueen                 152
#define IDM_Accept                      153
#define IDM_Decline                     154
#define IDM_StopObserving               155
#define IDM_StopExamining               156
#define IDM_Revert                      157
#define IDM_TruncateGame                158
#define IDM_MoveNow                     159
#define IDM_RetractMove                 160
#define IDM_Autobs                      161
#define IDM_QuietPlay                   162
#define IDM_ShowThinking                163
#define IDM_MailMove                    164
#define IDM_ReloadCMailMsg              165
#define IDM_Book                        166
#define IDM_AboutGame                   167
#define IDM_LocalEdit                   168
#define IDM_AutoComment                 169
#define IDM_ShowGameList                170
#define IDM_EditTags                    171
#define IDM_GetMoveList                 172
#define IDM_DefaultColors               173
#define IDM_Debug                       174
#define IDM_CheckLegality               175
#define IDM_TestLegality                175
#define IDM_Colorize                    176
#define IDM_DontColorize                176
#define IDM_AnalysisMode                177
#define IDM_AnalyzeFile                 178
#define IDM_PeriodicUpdates             179
#define OPT_TCtext1                     202
#define OPT_TCTime                      203
#define OPT_TCtext2                     204
#define OPT_Autosave                    206
#define OPT_AVPrompt                    208
#define OPT_AVToFile                    209
#define OPT_AVFilename                  210
#define OPT_Autostep                    214
#define OPT_ASTimeDelay                 215
#define OPT_AStext1                     216
#define OPT_TCMoves                     217
#define IDM_Tiny                        250
#define IDM_Teeny                       251
#define IDM_Dinky                       252
#define IDM_Petite                      253
#define IDM_Slim                        254
#define IDM_Small                       255
#define IDM_Mediocre                    256
#define IDM_Middling                    257
#define IDM_Average                     258
#define IDM_Moderate                    259
#define IDM_Medium                      260
#define IDM_Bulky                       261
#define IDM_Large                       262
#define IDM_HELPCONTENTS                300
#define IDM_HELPSEARCH                  301
#define IDM_HELPHELP                    302
#define IDM_ABOUT                       303
#define IDM_CommandX                    350
#define IDM_CommandXLast                399
#define DLG_TimeControl                 400
#define ABOUTBOX_Version                401
#define OPT_TCUseMoves                  402
#define OPT_TCUseInc                    403
#define OPT_TCitext1                    405
#define OPT_TCitext2                    406
#define OPT_TCInc                       407
#define OPT_TCitext3                    408
#define OPT_TCTime2                     409
#define DLG_Promotion                   500
#define PB_Queen                        502
#define PB_Rook                         503
#define PB_Bishop                       504
#define PB_Knight                       505
#define EP_White                        600
#define EP_WhitePawn                    601
#define EP_WhiteKnight                  602
#define EP_WhiteBishop                  603
#define EP_WhiteRook                    604
#define EP_WhiteQueen                   605
#define EP_Black                        606
#define EP_BlackPawn                    607
#define EP_BlackKnight                  608
#define EP_BlackBishop                  609
#define EP_BlackRook                    610
#define EP_BlackQueen                   611
#define EP_EmptySquare                  612
#define EP_ClearBoard                   613
#define EP_WhiteKing                    614
#define EP_BlackKing                    615
#define DP_Pawn                         616
#define DP_Knight                       617
#define DP_Bishop                       618
#define DP_Rook                         619
#define DP_Queen                        620
#define DLG_LoadOptions                 700
#define DLG_SaveOptions                 800
#define OPT_PGN                         802
#define OPT_Old                         803
#define DLG_CommPort                    900
#define OPT_Port                        901
#define OPT_DataRate                    902
#define OPT_Bits                        903
#define OPT_Parity                      904
#define OPT_StopBits                    905
#define OPT_Flow                        910
#define OPT_SerialHelp                  911
#define DLG_BoardSize                   1000
#define OPT_Small                       1001
#define OPT_Medium                      1002
#define OPT_Large                       1003
#define DLG_EditComment                 1010
#define OPT_ClearComment                1011
#define OPT_EditComment                 1013
#define OPT_CommentText                 1014
#define DLG_ViewComment                 1020
#define DLG_GameList                    1030
#define OPT_GameListPrev                1030
#define OPT_GameListText                1031
#define OPT_GameListLoad                1032
#define OPT_GameListNext                1034
#define OPT_GameListClose               1035
#define DLG_EditTags                    1040
#define OPT_TagsText                    1041
#define DLG_Analysis                    1050
#define OPT_AnalysisText                1051
#define DLG_Error                       1060
#define OPT_ErrorIcon                   1082
#define IDD_DIALOG1                     1090
#define DLG_ConsoleRich                 1090
#define IDC_EDIT1                       1091
#define OPT_ConsoleText                 1091
#define OPT_CommandInput                1091
#define OPT_QuestionInput               1091
#define OPT_ChessEngineName             1091
#define OPT_WavFileName                 1091
#define OPT_IndexNumber                 1091
#define IDC_EDIT2                       1092
#define OPT_ConsoleInput                1092
#define OPT_AdditionalOptions           1092
#define OPT_ErrorText                   1093
#define DLG_Console                     1101
#define DLG_PromotionKing               1102
#define DLG_Colorize                    1106
#define DLG_Command                     1123
#define DLG_Question                    1123
#define DLG_Startup                     1124
#define DLG_Sound                       1127
#define DLG_IndexNumber                 1149
#define IDM_ColorShout                  1150
#define IDM_ColorSShout                 1151
#define IDM_ColorChannel1               1152
#define IDM_ColorChannel                1153
#define OPT_IndexNumberOld              1153
#define IDM_ColorKibitz                 1154
#define IDM_ColorTell                   1155
#define IDM_ColorChallenge              1156
#define IDM_ColorRequest                1157
#define IDM_ColorNormal                 1158
#define IDM_ConsoleFont                 1200
#define IDM_TagsFont                    1201
#define IDM_CommentsFont                1202
#define IDM_Rematch                     1203
#define IDM_DefaultColorization         1213
#define IDM_ConsoleBackground           1214
#define IDA_PAGEUP                      1216
#define IDA_PAGEDOWN                    1217
#define IDA_CTRLHOME                    1218
#define IDA_CTRLEND                     1219
#define IDA_TAB                         1221
#define IDM_SaveSettings                1223
#define IDM_Iconize                     1224
#define IDM_DirectCommand1              1226
#define IDM_DirectCommand2              1227
#define IDM_Copy                        1229
#define IDM_Paste                       1230
#define IDM_MatchX                      1231
#define IDM_ObserveX                    1232
#define IDM_FingerX                     1233
#define IDM_TellX                       1234
#define IDM_QuickPaste                  1235
#define IDM_MessageX                    1237
#define IDM_VarsX                       1238
#define IDM_Cut                         1240
#define IDM_Undo                        1242
#define IDM_SelectAll                   1243
#define IDM_PopupMoveErrors             1244
#define IDM_SoundMove                   1245
#define IDM_SoundBell                   1246
#define IDM_DefaultSounds               1247
#define IDM_SoundShout                  1248
#define IDM_SoundSShout                 1249
#define IDM_SoundChannel1               1250
#define IDM_SoundChannel                1251
#define IDM_SoundKibitz                 1252
#define IDM_SoundTell                   1253
#define IDM_SoundChallenge              1254
#define IDM_SoundRequest                1255
#define IDM_SaveSettingsOnExit          1256
#define IDM_Animate                     1257
#define IDM_Dragging                    1258
#define IDM_HighlightLastMove           1259
#define IDM_HighlightDragging           1260
#define IDM_AlwaysOnTop                 1261
#define IDM_LoadNextPosition            1262
#define IDM_ReloadPosition              1264
#define IDM_LoadPrevPosition            1265
#define IDM_PonderNextMove              1266
#define IDM_SquareHighlights            1267
#define PB_King                         1307
#define OPT_Bold                        1312
#define OPT_Italic                      1313
#define OPT_Underline                   1314
#define OPT_Strikeout                   1315
#define OPT_ChooseColor                 1316
#define OPT_Sample                      1318
#define OPT_CancelComment               1320
#define OPT_EditTags                    1325
#define OPT_TagsCancel                  1326
#define OPT_CommandText                 1327
#define OPT_QuestionText                1327
#define OPT_ChessEngine                 1328
#define OPT_ChessServer                 1329
#define OPT_View                        1330
#define OPT_ChessServerName             1331
#define OPT_NoSound                     1333
#define OPT_DefaultBeep                 1334
#define OPT_SystemSound                 1335
#define OPT_BuiltInSound                1336
#define OPT_WavFile                     1337
#define OPT_BuiltInSoundName            1339
#define OPT_SystemSoundName             1340
#define OPT_BrowseSound                 1341
#define OPT_PlaySound                   1342
#define OPT_AVBrowse                    1343
#define OPT_SecondChessEngineName       1344
#define OPT_AnyAdditional               1345
#define IDM_Minimize                    1400
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        1150
#define _APS_NEXT_COMMAND_VALUE         1268
#define _APS_NEXT_CONTROL_VALUE         1346
#define _APS_NEXT_SYMED_VALUE           1403
#endif
#endif

==> winboard-4_0_2-src.zip: winboard/resource.h <==
//{{NO_DEPENDENCIES}}
// Microsoft Developer Studio generated include file.
// Used by winboard.rc
//
#define IDM_NewGame                     100
#define IDM_LoadGame                    101
#define IDM_SaveGame                    102
#define IDM_Exit                        103
#define IDM_LoadPosition                104
#define IDM_SavePosition                105
#define IDM_EditPosition                106
#define IDM_FlipView                    107
#define IDM_MachineWhite                108
#define IDM_MachineBlack                109
#define IDM_TwoMachines                 110
#define IDM_EditGame                    111
#define IDM_Forward                     112
#define IDM_Backward                    113
#define IDM_ToEnd                       114
#define IDM_ToStart                     115
#define IDM_Pause                       116
#define IDM_CallFlag                    117
#define IDM_Draw                        118
#define IDM_Abort                       120
#define IDM_Adjourn                     122
#define IDM_Resign                      124
#define IDM_Hint                        125
#define IDM_IcsClient                   126
#define IDM_ShowCoords                  127
#define IDM_BoardSize                   128
#define IDM_Bell                        129
#define IDM_Autoflag                    130
#define IDM_TimeControl                 131
#define IDM_LoadOptions                 132
#define IDM_SaveOptions                 133
#define IDM_Monochrome                  134
#define IDM_LightSquares                135
#define IDM_DarkSquares                 136
#define IDM_WhitePieces                 137
#define IDM_BlackPieces                 138
#define IDM_MessageFont                 143
#define IDM_ClockFont                   144
#define IDM_CoordFont                   145
#define IDM_DefaultFonts                146
#define IDM_CommPort                    147
#define IDM_EditComment                 148
#define IDM_LoadNextGame                149
#define IDM_LoadPrevGame                150
#define IDM_ReloadGame                  151
#define IDM_AlwaysQueen                 152
#define IDM_Accept                      153
#define IDM_Decline                     154
#define IDM_StopObserving               155
#define IDM_StopExamining               156
#define IDM_Revert                      157
#define IDM_TruncateGame                158
#define IDM_MoveNow                     159
#define IDM_RetractMove                 160
#define IDM_Autobs                      161
#define IDM_QuietPlay                   162
#define IDM_ShowThinking                163
#define IDM_MailMove                    164
#define IDM_ReloadCMailMsg              165
#define IDM_Book                        166
#define IDM_AboutGame                   167
#define IDM_LocalEdit                   168
#define IDM_AutoComment                 169
#define IDM_ShowGameList                170
#define IDM_EditTags                    171
#define IDM_GetMoveList                 172
#define IDM_DefaultColors               173
#define IDM_Debug                       174
#define IDM_CheckLegality               175
#define IDM_TestLegality                175
#define IDM_Colorize                    176
#define IDM_DontColorize                176
#define IDM_AnalysisMode                177
#define IDM_AnalyzeFile                 178
#define IDM_PeriodicUpdates             179
#define OPT_TCtext1                     202
#define OPT_TCTime                      203
#define OPT_TCtext2                     204
#define OPT_Autosave                    206
#define OPT_AVPrompt                    208
#define OPT_AVToFile                    209
#define OPT_AVFilename                  210
#define OPT_Autostep                    214
#define OPT_ASTimeDelay                 215
#define OPT_AStext1                     216
#define OPT_TCMoves                     217
#define IDM_Tiny                        250
#define IDM_Teeny                       251
#define IDM_Dinky                       252
#define IDM_Petite                      253
#define IDM_Slim                        254
#define IDM_Small                       255
#define IDM_Mediocre                    256
#define IDM_Middling                    257
#define IDM_Average                     258
#define IDM_Moderate                    259
#define IDM_Medium                      260
#define IDM_Bulky                       261
#define IDM_Large                       262
#define IDM_Big                         263
#define IDM_Huge                        264
#define IDM_Giant                       265
#define IDM_Colossal                    266
#define IDM_Titanic                     267
#define IDM_HELPCONTENTS                300
#define IDM_HELPSEARCH                  301
#define IDM_HELPHELP                    302
#define IDM_ABOUT                       303
#define IDM_CommandX                    310
#define IDM_CommandXLast                399
#define DLG_TimeControl                 400
#define ABOUTBOX_Version                401
#define OPT_TCUseMoves                  402
#define OPT_TCUseInc                    403
#define OPT_TCitext1                    405
#define OPT_TCitext2                    406
#define OPT_TCInc                       407
#define OPT_TCitext3                    408
#define OPT_TCTime2                     409
#define DLG_Promotion                   500
#define PB_Queen                        502
#define PB_Rook                         503
#define PB_Bishop                       504
#define PB_Knight                       505
#define EP_White                        600
#define EP_WhitePawn                    601
#define EP_WhiteKnight                  602
#define EP_WhiteBishop                  603
#define EP_WhiteRook                    604
#define EP_WhiteQueen                   605
#define EP_Black                        606
#define EP_BlackPawn                    607
#define EP_BlackKnight                  608
#define EP_BlackBishop                  609
#define EP_BlackRook                    610
#define EP_BlackQueen                   611
#define EP_EmptySquare                  612
#define EP_ClearBoard                   613
#define EP_WhiteKing                    614
#define EP_BlackKing                    615
#define DP_Pawn                         616
#define DP_Knight                       617
#define DP_Bishop                       618
#define DP_Rook                         619
#define DP_Queen                        620
#define DLG_LoadOptions                 700
#define DLG_SaveOptions                 800
#define OPT_PGN                         802
#define OPT_Old                         803
#define DLG_CommPort                    900
#define OPT_Port                        901
#define OPT_DataRate                    902
#define OPT_Bits                        903
#define OPT_Parity                      904
#define OPT_StopBits                    905
#define OPT_Flow                        910
#define OPT_SerialHelp                  911
#define DLG_BoardSize                   1000
#define OPT_Small                       1001
#define OPT_Medium                      1002
#define OPT_Large                       1003
#define DLG_EditComment                 1010
#define OPT_ClearComment                1011
#define OPT_EditComment                 1013
#define OPT_CommentText                 1014
#define DLG_ViewComment                 1020
#define DLG_GameList                    1030
#define OPT_GameListPrev                1030
#define OPT_GameListText                1031
#define OPT_GameListLoad                1032
#define OPT_GameListNext                1034
#define OPT_GameListClose               1035
#define DLG_EditTags                    1040
#define OPT_TagsText                    1041
#define DLG_Analysis                    1050
#define OPT_AnalysisText                1051
#define DLG_Error                       1060
#define OPT_ErrorIcon                   1082
#define IDD_DIALOG1                     1090
#define DLG_ConsoleRich                 1090
#define IDC_EDIT1                       1091
#define OPT_ConsoleText                 1091
#define OPT_CommandInput                1091
#define OPT_QuestionInput               1091
#define OPT_ChessEngineName             1091
#define OPT_WavFileName                 1091
#define OPT_IndexNumber                 1091
#define OPT_Move                        1091
#define IDC_EDIT2                       1092
#define OPT_ConsoleInput                1092
#define OPT_AdditionalOptions           1092
#define OPT_ErrorText                   1093
#define DLG_Console                     1101
#define DLG_PromotionKing               1102
#define DLG_Colorize                    1106
#define DLG_Command                     1123
#define DLG_Question                    1123
#define DLG_Startup                     1124
#define DLG_Sound                       1127
#define DLG_IndexNumber                 1149
#define IDM_ColorShout                  1150
#define DLG_TypeInMove                  1150
#define IDM_ColorSShout                 1151
#define IDM_ColorChannel1               1152
#define IDM_ColorChannel                1153
#define OPT_IndexNumberOld              1153
#define IDM_ColorKibitz                 1154
#define IDM_ColorTell                   1155
#define IDM_ColorChallenge              1156
#define IDM_ColorRequest                1157
#define IDM_ColorNormal                 1158
#define IDM_ConsoleFont                 1200
#define IDM_TagsFont                    1201
#define IDM_CommentsFont                1202
#define IDM_Rematch                     1203
#define IDM_DefaultColorization         1213
#define IDM_ConsoleBackground           1214
#define IDA_PAGEUP                      1216
#define IDA_PAGEDOWN                    1217
#define IDA_CTRLHOME                    1218
#define IDA_CTRLEND                     1219
#define IDA_TAB                         1221
#define IDM_SaveSettings                1223
#define IDM_Iconize                     1224
#define IDM_DirectCommand1              1226
#define IDM_DirectCommand2              1227
#define IDM_Copy                        1229
#define IDM_Paste                       1230
#define IDM_MatchX                      1231
#define IDM_ObserveX                    1232
#define IDM_FingerX                     1233
#define IDM_TellX                       1234
#define IDM_QuickPaste                  1235
#define IDM_MessageX                    1237
#define IDM_VarsX                       1238
#define IDM_Cut                         1240
#define IDM_Undo                        1242
#define IDM_SelectAll                   1243
#define IDM_PopupMoveErrors             1244
#define IDM_SoundMove                   1245
#define IDM_SoundBell                   1246
#define IDM_DefaultSounds               1247
#define IDM_SoundShout                  1248
#define IDM_SoundSShout                 1249
#define IDM_SoundChannel1               1250
#define IDM_SoundChannel                1251
#define IDM_SoundKibitz                 1252
#define IDM_SoundTell                   1253
#define IDM_SoundChallenge              1254
#define IDM_SoundRequest                1255
#define IDM_SaveSettingsOnExit          1256
#define IDM_Animate                     1257
#define IDM_Dragging                    1258
#define IDM_HighlightLastMove           1259
#define IDM_HighlightDragging           1260
#define IDM_AlwaysOnTop                 1261
#define IDM_LoadNextPosition            1262
#define IDM_ReloadPosition              1264
#define IDM_LoadPrevPosition            1265
#define IDM_PonderNextMove              1266
#define IDM_SquareHighlights            1267
#define IDM_TypeInMove                  1268
#define PB_King                         1307
#define OPT_Bold                        1312
#define OPT_Italic                      1313
#define OPT_Underline                   1314
#define OPT_Strikeout                   1315
#define OPT_ChooseColor                 1316
#define OPT_Sample                      1318
#define OPT_CancelComment               1320
#define OPT_EditTags                    1325
#define OPT_TagsCancel                  1326
#define OPT_CommandText                 1327
#define OPT_QuestionText                1327
#define OPT_ChessEngine                 1328
#define OPT_ChessServer                 1329
#define OPT_View                        1330
#define OPT_ChessServerName             1331
#define OPT_NoSound                     1333
#define OPT_DefaultBeep                 1334
#define OPT_SystemSound                 1335
#define OPT_BuiltInSound                1336
#define OPT_WavFile                     1337
#define OPT_BuiltInSoundName            1339
#define OPT_SystemSoundName             1340
#define OPT_BrowseSound                 1341
#define OPT_PlaySound                   1342
#define OPT_AVBrowse                    1343
#define OPT_SecondChessEngineName       1344
#define OPT_AnyAdditional               1345
#define IDM_Minimize                    1400
#define IDC_STATIC                      -1

// Next default values for new objects
// 
#ifdef APSTUDIO_INVOKED
#ifndef APSTUDIO_READONLY_SYMBOLS
#define _APS_NO_MFC                     1
#define _APS_NEXT_RESOURCE_VALUE        1213
#define _APS_NEXT_COMMAND_VALUE         1274
#define _APS_NEXT_CONTROL_VALUE         1346
#define _APS_NEXT_SYMED_VALUE           1403
#endif
#endif
